<?php

/**
 * @file
 * FVL configuration file.
 */

/**
 * Callback for the admin configuration page.
 */
function fvl_admin_settings($form, &$form_state) {
  $settings = variable_get('fvl_fields', array());
  $form = array();
  $instances = field_info_instances();
  $form_state['entity_array'] = array();

  $form['show_link_text'] = array(
    '#type' => 'textfield',
    '#title' => t('Text for the link to "show"'),
    '#default_value' => variable_get('fvl_show_link_text', 'Show'),
    '#required' => TRUE,
  );
  $form['fields'] = array(
    '#type' => 'container',
    '#prefix' => '<h3>' . t('Select a field(s) for each of entity and bundle that should be handled module:') . '</h3>',
  );
  // Creating list of fields for each entity and bundle having a field(s).
  foreach ($instances as $entity_name => $bundles) {
    $entity_info = entity_get_info($entity_name);
    if (!$entity_info['fieldable']) {
      continue;
    }
    $form['fields'][$entity_name] = array(
      '#type' => 'fieldset',
      '#title' => t('Entity: @label', array('@label' => $entity_info['label'])),
      '#collapsible' => TRUE,
      '#collapsed' => isset($settings[$entity_name]) ? FALSE : TRUE,
      '#tree' => TRUE,
    );
    $empty = TRUE;
    foreach ($bundles as $bundle_name => $fields) {
      if ($fields) {
        $empty = FALSE;
        $form['fields'][$entity_name][$bundle_name] = array(
          '#type' => 'fieldset',
          '#title' => t('Bundle: @label', array('@label' => $entity_info['bundles'][$bundle_name]['label'])),
          '#collapsible' => TRUE,
          '#collapsed' => isset($settings[$entity_name][$bundle_name]) ? FALSE : TRUE,
        );
        foreach ($fields as $field) {
          $form['fields'][$entity_name][$bundle_name][$field['field_name']] = array(
            '#type' => 'checkbox',
            '#title' => $field['label'],
            '#default_value' => isset($settings[$entity_name][$bundle_name][$field['field_name']]),
          );
        }
      }
    }
    if ($empty) {
      unset($form['fields'][$entity_name]);
    }
    else {
      $form_state['entity_array'][] = $entity_name;
    }
  }
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save configuration'),
  );

  return $form;
}

/**
 * Configuration form submit.
 */
function fvl_admin_settings_submit($form, $form_state) {
  $settings = array();
  $values = $form_state['values'];

  foreach ($form_state['entity_array'] as $entity) {
    foreach ($values[$entity] as $bandle => $fields) {
      foreach ($fields as $field => $value) {
        if ($values[$entity][$bandle][$field]) {
          $settings[$entity][$bandle][$field] = TRUE;
        }
      }
    }
  }
  variable_set('fvl_show_link_text', $values['show_link_text']);
  variable_set('fvl_fields', $settings);
  drupal_set_message(t('The configuration options have been saved.'));
}
